==> tutti-ui-swing-3.4-sources.jar: fr/ifremer/tutti/ui/swing/action/ImportPupitriAction.java <==
package fr.ifremer.tutti.ui.swing.action;

/*
 * #%L
 * Tutti :: UI
 * $Id: ImportPupitriAction.java 1566 2014-02-04 08:31:02Z tchemit $
 * $HeadURL: https://svn.codelutin.com/tutti/tags/tutti-3.4/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/action/ImportPupitriAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.Joiner;
import com.google.common.collect.Lists;
import fr.ifremer.tutti.persistence.entities.data.CatchBatch;
import fr.ifremer.tutti.persistence.entities.data.FishingOperation;
import fr.ifremer.tutti.persistence.entities.data.SampleCategoryModel;
import fr.ifremer.tutti.persistence.service.TuttiEnumerationFile;
import fr.ifremer.tutti.service.PersistenceService;
import fr.ifremer.tutti.service.pupitri.PupitriImportExportService;
import fr.ifremer.tutti.service.pupitri.PupitriImportResult;
import fr.ifremer.tutti.ui.swing.content.operation.FishingOperationsUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.EditCatchesUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.EditCatchesUIModel;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.ImportPupitriPopupUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUIHandler;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUIModel;
import fr.ifremer.tutti.ui.swing.util.AbstractTuttiUIHandler;

import javax.swing.JOptionPane;
import javax.swing.UIManager;
import java.io.File;
import java.util.List;

import static org.nuiton.i18n.I18n.t;

/**
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ImportPupitriAction extends AbstractTuttiAction<SpeciesBatchUIModel, SpeciesBatchUI, SpeciesBatchUIHandler> {

    protected File importedTrunkFile;

    protected File importedCarrouselFile;

    protected ImportPupitriPopupUI importPupitriDialog;

    protected PersistenceService persistenceService;

    protected EditFishingOperationAction editAction;

    protected PupitriImportResult importResult;

    public ImportPupitriAction(SpeciesBatchUIHandler handler) {
        super(handler, false);
        persistenceService = getContext().getPersistenceService();
        importPupitriDialog = new ImportPupitriPopupUI(handler.getContext());
    }

    public EditFishingOperationAction getEditAction() {
        if (editAction == null) {
            FishingOperationsUI parentContainer = handler.getParentContainer(FishingOperationsUI.class);
            editAction = getContext().getActionFactory().createLogicAction(parentContainer.getHandler(),
                                                                           EditFishingOperationAction.class);
        }
        return editAction;
    }

    @Override
    public boolean prepareAction() throws Exception {
        boolean result = true;

        // must check that sample category model is compatible for pupitri import
        // means need some categories

        TuttiEnumerationFile enumerationFile = persistenceService.getEnumerationFile();
        SampleCategoryModel sampleCategoryModel = getDataContext().getSampleCategoryModel();

        List<String> missingCategories = Lists.newArrayList();
        if (!sampleCategoryModel.containsCategoryId(enumerationFile.PMFM_ID_SIZE_CATEGORY)) {
            missingCategories.add("<li>" + persistenceService.getSizeCategoryCaracteristic().getParameterName() + "</li>");
        }
        if (!sampleCategoryModel.containsCategoryId(enumerationFile.PMFM_ID_SEX)) {
            missingCategories.add("<li>" + persistenceService.getSexCaracteristic().getParameterName() + "</li>");
        }
        if (!missingCategories.isEmpty()) {
            result = false;
            JOptionPane.showMessageDialog(
                    getContext().getActionUI(),
                    t("tutti.editSpeciesBatch.action.importPupitri.invalidSampleCategoryModel.message", Joiner.on("").join(missingCategories)),
                    t("tutti.editSpeciesBatch.action.importPupitri.invalidSampleCategoryModel.title"),
                    JOptionPane.ERROR_MESSAGE,
                    UIManager.getIcon("error")
            );
        }
        if (result) {

            SpeciesBatchUIModel speciesBatchUIModel = getUI().getModel();
            if (speciesBatchUIModel.getRowCount() > 0) {
                String htmlMessage = String.format(
                        AbstractTuttiUIHandler.CONFIRMATION_FORMAT,
                        t("tutti.editSpeciesBatch.action.importPupitri.existingData.message"),
                        t("tutti.editSpeciesBatch.action.importPupitri.existingData.help"));

                int answer = JOptionPane.showConfirmDialog(getContext().getActionUI(),
                                                           htmlMessage,
                                                           t("tutti.editSpeciesBatch.action.importPupitri.existingData.title"),
                                                           JOptionPane.OK_CANCEL_OPTION,
                                                           JOptionPane.WARNING_MESSAGE);

                result = answer == JOptionPane.OK_OPTION;
            }
        }

        if (result) {
            importPupitriDialog.open();
            importedTrunkFile = importPupitriDialog.getTrunkFile().getSelectedFile();
            importedCarrouselFile = importPupitriDialog.getCarrouselFile().getSelectedFile();
            result = importedTrunkFile != null
                     && importedCarrouselFile != null;
        }

        return result;
    }

    @Override
    public void doAction() throws Exception {
        PupitriImportExportService importExportService =
                getContext().getTuttiPupitriImportExportService();

        EditCatchesUI parentContainer = handler.getParentContainer(EditCatchesUI.class);
        EditCatchesUIModel model = parentContainer.getModel();

        FishingOperation operation = model.getFishingOperation();
        CatchBatch catchBatch = model.toEntity();

        // import
        importResult = importExportService.importPupitri(importedTrunkFile,
                                                         importedCarrouselFile,
                                                         operation,
                                                         catchBatch);

        if (importResult.isFishingOperationFound()) {

            // reload operation
            getEditAction().loadCatchBatch(operation);
        }
    }

    @Override
    public void releaseAction() {
        super.releaseAction();
        importedTrunkFile = null;
        importedCarrouselFile = null;
    }

    @Override
    public void postSuccessAction() {
        super.postSuccessAction();

        if (importResult.isFishingOperationFound()) {
            int rejectedSpeciesNb = importResult.getNbCarrousselNotImported();

            sendMessage(t("tutti.editSpeciesBatch.action.importPupitri.success",
                          getModel().getRootNumber(), rejectedSpeciesNb));
        } else {

            displayWarningMessage(
                    t("tutti.editSpeciesBatch.action.importPupitri.no.matching.fishingOperation.title"),
                    "<html><body>" +
                    t("tutti.editSpeciesBatch.action.importPupitri.no.matching.fishingOperation") +
                    "</body></html>"
            );
            sendMessage(t("tutti.editSpeciesBatch.action.importPupitri.no.matching.data"));
        }
    }
}

==> tutti-ui-swing-3.4.1-sources.jar: fr/ifremer/tutti/ui/swing/action/ImportPupitriAction.java <==
package fr.ifremer.tutti.ui.swing.action;

/*
 * #%L
 * Tutti :: UI
 * $Id: ImportPupitriAction.java 1566 2014-02-04 08:31:02Z tchemit $
 * $HeadURL: https://svn.codelutin.com/tutti/tags/tutti-3.4.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/action/ImportPupitriAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.Joiner;
import com.google.common.collect.Lists;
import fr.ifremer.tutti.persistence.entities.data.CatchBatch;
import fr.ifremer.tutti.persistence.entities.data.FishingOperation;
import fr.ifremer.tutti.persistence.entities.data.SampleCategoryModel;
import fr.ifremer.tutti.persistence.service.TuttiEnumerationFile;
import fr.ifremer.tutti.service.PersistenceService;
import fr.ifremer.tutti.service.pupitri.PupitriImportExportService;
import fr.ifremer.tutti.service.pupitri.PupitriImportResult;
import fr.ifremer.tutti.ui.swing.content.operation.FishingOperationsUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.EditCatchesUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.EditCatchesUIModel;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.ImportPupitriPopupUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUIHandler;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUIModel;
import fr.ifremer.tutti.ui.swing.util.AbstractTuttiUIHandler;

import javax.swing.JOptionPane;
import javax.swing.UIManager;
import java.io.File;
import java.util.List;

import static org.nuiton.i18n.I18n.t;

/**
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ImportPupitriAction extends AbstractTuttiAction<SpeciesBatchUIModel, SpeciesBatchUI, SpeciesBatchUIHandler> {

    protected File importedTrunkFile;

    protected File importedCarrouselFile;

    protected ImportPupitriPopupUI importPupitriDialog;

    protected PersistenceService persistenceService;

    protected EditFishingOperationAction editAction;

    protected PupitriImportResult importResult;

    public ImportPupitriAction(SpeciesBatchUIHandler handler) {
        super(handler, false);
        persistenceService = getContext().getPersistenceService();
        importPupitriDialog = new ImportPupitriPopupUI(handler.getContext());
    }

    public EditFishingOperationAction getEditAction() {
        if (editAction == null) {
            FishingOperationsUI parentContainer = handler.getParentContainer(FishingOperationsUI.class);
            editAction = getContext().getActionFactory().createLogicAction(parentContainer.getHandler(),
                                                                           EditFishingOperationAction.class);
        }
        return editAction;
    }

    @Override
    public boolean prepareAction() throws Exception {
        boolean result = true;

        // must check that sample category model is compatible for pupitri import
        // means need some categories

        TuttiEnumerationFile enumerationFile = persistenceService.getEnumerationFile();
        SampleCategoryModel sampleCategoryModel = getDataContext().getSampleCategoryModel();

        List<String> missingCategories = Lists.newArrayList();
        if (!sampleCategoryModel.containsCategoryId(enumerationFile.PMFM_ID_SIZE_CATEGORY)) {
            missingCategories.add("<li>" + persistenceService.getSizeCategoryCaracteristic().getParameterName() + "</li>");
        }
        if (!sampleCategoryModel.containsCategoryId(enumerationFile.PMFM_ID_SEX)) {
            missingCategories.add("<li>" + persistenceService.getSexCaracteristic().getParameterName() + "</li>");
        }
        if (!missingCategories.isEmpty()) {
            result = false;
            JOptionPane.showMessageDialog(
                    getContext().getActionUI(),
                    t("tutti.editSpeciesBatch.action.importPupitri.invalidSampleCategoryModel.message", Joiner.on("").join(missingCategories)),
                    t("tutti.editSpeciesBatch.action.importPupitri.invalidSampleCategoryModel.title"),
                    JOptionPane.ERROR_MESSAGE,
                    UIManager.getIcon("error")
            );
        }
        if (result) {

            SpeciesBatchUIModel speciesBatchUIModel = getUI().getModel();
            if (speciesBatchUIModel.getRowCount() > 0) {
                String htmlMessage = String.format(
                        AbstractTuttiUIHandler.CONFIRMATION_FORMAT,
                        t("tutti.editSpeciesBatch.action.importPupitri.existingData.message"),
                        t("tutti.editSpeciesBatch.action.importPupitri.existingData.help"));

                int answer = JOptionPane.showConfirmDialog(getContext().getActionUI(),
                                                           htmlMessage,
                                                           t("tutti.editSpeciesBatch.action.importPupitri.existingData.title"),
                                                           JOptionPane.OK_CANCEL_OPTION,
                                                           JOptionPane.WARNING_MESSAGE);

                result = answer == JOptionPane.OK_OPTION;
            }
        }

        if (result) {
            importPupitriDialog.open();
            importedTrunkFile = importPupitriDialog.getTrunkFile().getSelectedFile();
            importedCarrouselFile = importPupitriDialog.getCarrouselFile().getSelectedFile();
            result = importedTrunkFile != null
                     && importedCarrouselFile != null;
        }

        return result;
    }

    @Override
    public void doAction() throws Exception {
        PupitriImportExportService importExportService =
                getContext().getTuttiPupitriImportExportService();

        EditCatchesUI parentContainer = handler.getParentContainer(EditCatchesUI.class);
        EditCatchesUIModel model = parentContainer.getModel();

        FishingOperation operation = model.getFishingOperation();
        CatchBatch catchBatch = model.toEntity();

        // import
        importResult = importExportService.importPupitri(importedTrunkFile,
                                                         importedCarrouselFile,
                                                         operation,
                                                         catchBatch);

        if (importResult.isFishingOperationFound()) {

            // reload operation
            getEditAction().loadCatchBatch(operation);
        }
    }

    @Override
    public void releaseAction() {
        super.releaseAction();
        importedTrunkFile = null;
        importedCarrouselFile = null;
    }

    @Override
    public void postSuccessAction() {
        super.postSuccessAction();

        if (importResult.isFishingOperationFound()) {
            int rejectedSpeciesNb = importResult.getNbCarrousselNotImported();

            sendMessage(t("tutti.editSpeciesBatch.action.importPupitri.success",
                          getModel().getRootNumber(), rejectedSpeciesNb));
        } else {

            displayWarningMessage(
                    t("tutti.editSpeciesBatch.action.importPupitri.no.matching.fishingOperation.title"),
                    "<html><body>" +
                    t("tutti.editSpeciesBatch.action.importPupitri.no.matching.fishingOperation") +
                    "</body></html>"
            );
            sendMessage(t("tutti.editSpeciesBatch.action.importPupitri.no.matching.data"));
        }
    }
}
